# Shareable configurations

A shareable configuration is an [npm](https://www.npmjs.com/) package that exports a **semantic-release** configuration object. It allows for use of the same configuration across several projects.

The shareable configurations to use can be set with the [extends](configuration.md#extends) option.

See [shareable configurations list](../extending/shareable-configurations-list.md).
